@@ -115,11 +115,7 @@ def submit_bit_vectors(base_url: str, secret: str, bit_vectors: List[str]):
 
     # create submission request object
     submit_request = {
-        "bit-vectors": [
-            {
-                "bit-vector": s
-            } for s in bit_vectors
-        ]
+        "bitVectors": bit_vectors
     }
 
     r = requests.post(url, json=submit_request, headers=append_auth_header(secret))
