@@ -10,24 +10,21 @@ def serialize_match_config(config: MatchConfig) -> Dict:
     :param config: Match configuration to convert
     :return: Converted match configuration
     """
-    return {
-        "match-function": config.match_function,
-        "selection-strategy": config.selection_strategy,
-        "threshold": str(config.threshold),
-        "match-mode": config.match_mode
-    }
+    d = {}
 
+    if config.match_function is not None:
+        d["matchFunction"] = config.match_function
 
-def serialize_bit_vector(bit_vector: str) -> Dict:
-    """
-    Converts a bit vector into a dictionary.
+    if config.selection_strategy is not None:
+        d["selectionStrategy"] = config.selection_strategy
 
-    :param bit_vector: Bit vector to convert
-    :return: Converted bit vector
-    """
-    return {
-        "bit-vector": bit_vector
-    }
+    if config.threshold is not None:
+        d["threshold"] = config.threshold
+
+    if config.match_mode is not None:
+        d["matchMode"] = config.match_mode
+
+    return d
 
 
 def serialize_match_request(request: MatchRequest) -> Dict:
@@ -38,13 +35,9 @@ def serialize_match_request(request: MatchRequest) -> Dict:
     :return: Converted match request
     """
     return {
-        "domain-entity-list": [
-            serialize_bit_vector(d) for d in request.domain_bit_vectors
-        ],
-        "range-entity-list": [
-            serialize_bit_vector(r) for r in request.range_bit_vectors
-        ],
-        "match-configuration": serialize_match_config(request.match_config),
+        "domain": request.domain,
+        "range": request.range,
+        "config": serialize_match_config(request.match_config),
     }
 
 
@@ -56,7 +49,7 @@ def deserialize_match(d: Dict) -> Match:
     :return: Converted dictionary
     """
     return Match(
-        domain_bit_vector=d["domain-bit-vector"],
-        range_bit_vector=d["range-bit-vector"],
+        domain_vector=d["domain"],
+        range_vector=d["range"],
         confidence=d["confidence"]
     )
