@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
-from typing import List
+from typing import List, Optional
 
 
 @dataclass(frozen=True)
@@ -7,10 +7,10 @@ class MatchConfig:
     """
     Represents a match configuration that can be used to request matching at a match service.
     """
-    match_function: str = "TRIGRAM_DICE"
-    selection_strategy: str = "FULL_RESULT"
-    threshold: float = 0
-    match_mode: str = "MATCH_MODE"
+    match_function: Optional[str] = None
+    selection_strategy: Optional[str] = None
+    threshold: Optional[float] = None
+    match_mode: Optional[str] = None
 
 
 @dataclass(frozen=True)
@@ -18,8 +18,8 @@ class MatchRequest:
     """
     Represents a request to match the domain bit strings against the range bit strings.
     """
-    domain_bit_vectors: List[str] = field(default_factory=list)
-    range_bit_vectors: List[str] = field(default_factory=list)
+    domain: List[str] = field(default_factory=list)
+    range: List[str] = field(default_factory=list)
     match_config: MatchConfig = field(default_factory=MatchConfig)
 
 
@@ -28,6 +28,6 @@ class Match:
     """
     Represents a match returned by the match service.
     """
-    domain_bit_vector: str
-    range_bit_vector: str
+    domain_vector: str
+    range_vector: str
     confidence: float
