@@ -1,7 +1,7 @@
 from dataclasses import dataclass, field
 from typing import List
 
-from ..encoder import EncoderConfig
+from ..encoder import BloomFilterConfig
 
 
 @dataclass(frozen=True)
@@ -19,7 +19,7 @@ class ResolveRequest:
     Represents a request to resolve and submit pseudonyms to a broker service.
     """
     client_config: ClientConfig = field(default_factory=ClientConfig)
-    encoder_config: EncoderConfig = field(default_factory=EncoderConfig)
+    encoder_bloom_config: BloomFilterConfig = field(default_factory=BloomFilterConfig)
     pseudonyms: List[str] = field(default_factory=list)
 
 
